#include <iostream>
#include <QtCore>
#include <QtDebug>
#include "httpget.h"

HttpGet::HttpGet(QObject *parent) :
        QObject(parent)
{
    myHttp = new QHttp();
    myBuffer = NULL;
    connect(myHttp, SIGNAL(requestFinished(int, bool)), this, SLOT(httpDone(int, bool)));
    connect(myHttp, SIGNAL(stateChanged(int)), this, SLOT(changeState(int)));
    connect(myHttp, SIGNAL(responseHeaderReceived(QHttpResponseHeader)), this, SLOT(gotResponse(QHttpResponseHeader)));

}

HttpGet::~HttpGet() {
    myHttp->abort();
    delete myHttp;
    qDebug()<<"complete";
}

bool HttpGet::getFile(const QUrl &url, const QString& filename) {
    myUrl = url;
    myFileName = filename;
    myUrl.setPath(myUrl.path()+filename);
    if (!myUrl.isValid()) {
        std::cerr<<"Error: Invalid URL"<<std::endl;
        return false;
    }
    if (myUrl.path().isEmpty()) {
        std::cerr<<"Error: Path is empty"<<std::endl;
        return false;
    }
    myHttp->setHost(myUrl.host(), myUrl.port(80));
    isAborted = false;
    if (myBuffer != NULL)
        delete myBuffer;
    myBuffer = new QBuffer();
    myBuffer->open(QBuffer::ReadWrite);
    reqId = myHttp->get(myUrl.path(), myBuffer);
    myHttp->close();
    return true;
}

void HttpGet::httpDone(int id, bool error) {
    if (id != reqId)
        return;
    if (isAborted || myResponseState != 200)
        error = true;
    qDebug()<<"done: "<<myFileName<<" size: "<<myBuffer->data().size();
    if (error) {
        std::cerr<<qPrintable(myHttp->errorString())<<std::endl;
    }
    emit done(error);
}

void HttpGet::changeState(int state) {
    qDebug()<<"state: "<<state<<" "<<myFileName<<" size: "<<myBuffer->data().size();
    if (state == QHttp::Unconnected) {
        emit finished();
        //myHttp->close();
    }
}

void HttpGet::abort() {
    myHttp->abort();
    isAborted = true;
}

void HttpGet::gotResponse(QHttpResponseHeader header) {
    myResponseState = header.statusCode();
}

void HttpGet::close() {
    myBuffer->close();
    delete myBuffer;
    myBuffer = NULL;
}
