#include <iostream>
#include <QCoreApplication>
#include <QString>
#include <QtCore>
#include <QPainter>
#include <QPicture>
#include <QImage>
#include <QtDebug>
#include "projection.h"
#include "srtm.h"
#include "marchingsquare.h"

void usage(QString prog) {
    std::cout<<"Usage: "<<prog.toStdString()
            <<" [- o outDir] [-s srtmDir] [-m maxZoom] tilenumber"<<std::endl;
    std::cout<<"  Tilenumber: zoom_x_y[.png]"<<std::endl;
    std::cout<<"Default values:"<<std::endl;
    std::cout<<"  -o ."<<std::endl;
    std::cout<<"  -s ."<<std::endl;
    std::cout<<"  -m 15"<<std::endl;
    std::cout<<"Example:"<<std::endl;
    std::cout<<"  "<<prog.toStdString()<<" -s srtm -o tiles 11_1096_693.png"<<std::endl;
}

int main(int argc, char *argv[])
{
    QString outDir = ".";
    QString srtmDir = ".";
    int maxZoom = 15;
    QCoreApplication app(argc, argv);
    QStringList args = app.arguments();
    if (args.size() == 1) {
        //args<<"-s"<<"srtm"<<"-o"<<"./srtm"<<"."<<"11_1096_693.png";
        usage(args[0]);
        exit(0);
    }
    qDebug()<<args;
    for (int k = 1; k < args.size()-1; k++) {
        if (args[k] == "-o") {
            outDir = args[k+1];
            k++;
        }
        else if (args[k] == "-s") {
            srtmDir = args[k+1];
            k++;
        }
        else if (args[k] == "-m") {
            maxZoom = args[k+1].toInt();
            k++;
        }
    }
    QStringList xtile = args[args.size()-1].split(".");
    QStringList stile = xtile[0].split("_");
    //qDebug()<<" args "<<stile;
    int zoom = stile[0].toInt();
    QPoint tile(stile[1].toInt(), stile[2].toInt());
    Srtm srtm(zoom, tile);
    srtm.setOutDir(outDir);
    srtm.setSrtmDir(srtmDir);
    srtm.setMaxZoom(maxZoom);
    srtm.run();
    qDebug()<<"main end";
    return 0;
}
