#ifndef SRTM_H
#define SRTM_H

#include <QObject>
#include <QList>
#include <QPainter>
#include <QPoint>
#include <QString>
#include <cairo.h>
#include "httpget.h"

#define SRTM_URL "http://dds.cr.usgs.gov/srtm/version2_1/SRTM3/Eurasia/"

class EleLine {
private:
    int myElevation;
    QList<QPointF> myPoints;
public:
    EleLine(int elevation);
    int elevation() const { return myElevation; }
    const QList<QPointF>& points() const { return myPoints; }
    void append(QPointF point) { myPoints.append(point); }
};

class TileRequest {
private:
    int myZ;
    int myX;
    int myY;
public:
    TileRequest(int z, int x, int y) : myZ(z), myX(x), myY(y) {}
    int z() { return myZ; }
    int x() { return myX; }
    int y() { return myY; }
};

class Srtm : public QObject
{
private:
    int myMaxZoom;
    int myZoom;
    QPoint myTile0;
    QPointF myLonLat0;
    QString srtmDir;
    QString outDir;
    QPointF myP0;
    QPointF myBb0, myBb1;
    QList<EleLine> eleLines;
    int *myMesh;
    void requestFiles(const QStringList& fileRequests);
    void wget(QString url, QString fileName);
    void unzip(QString filename);
    int *readfile(QString filename);
    int *copy1(int *mesh, int ox, int oy, int nx, int ny);
    int *copy4(int *m00, int *m10, int *m01, int *m11);
    void cleanData(int *mesh, int ix, int iy);
    void showMesh(int *mesh, int nx, int ny, QString filename);
    QPoint elevationBounds(int *mesh, int nx, int ny) const;
    void createContour(const QPointF& p0, int *mAll);
    void drawTiles();
    void drawTile(QList<TileRequest> &requests);
    bool pointIsVisible(const QPointF& p) const;
    //void drawPolyLine(QPainter* painter, const QList<QPointF>& points, double width, QString text);
    //void drawLinePart(QPainter* painter, const QList<QPointF>& pts, double width, QString text);
    void drawPolyLine(cairo_t *cr, const QList<QPointF>& points, double width, QString text);
    void drawLinePart(cairo_t *cr, const QList<QPointF>& pts, double width, QString text);

public:
    Srtm(int zoom, const QPoint& tile);
    virtual ~Srtm();
    void setOutDir(const QString& val) { outDir = val; }
    void setSrtmDir(const QString& val) {srtmDir = val; }
    void setMaxZoom(const int& zoom) { myMaxZoom = zoom; }
    QString fileName(const QPointF& lonLat);
    int *mesh() { return myMesh; }
    void run();
};

#endif // SRTM_H
